import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

//Specifying dataset URL
const csvUrl = 'https://gist.githubusercontent.com/cosmos225/c3e1b87be517b12acbf86cba6ad908aa/raw/7c25a699328a91359608dcf1deea8605154b2429/iris.csv';

//Specifying which rows from the dataset to parse
const parseRow = (d) => {
  d['SepalLengthCm'] = +d['SepalLengthCm'];
  d['SepalWidthCm'] = +d['SepalWidthCm'];
  d['PetalLengthCm'] = +d['PetalLengthCm'];
  d['PetalWidthCm'] = +d['PetalWidthCm'];
  return d;
};

//Defining constant width and height attributes for the chart
const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);


//Main Function
const main = async () => {
  svg.call(
    scatterPlot() //Calling scatterPlot.js function with 
      .width(width)
      .height(height)
      .data(await csv(csvUrl, parseRow))
      .xValue((d) => d['PetalWidthCm']) //Setting X-axis as Petal width
      .yValue((d) => d['SepalLengthCm']) //Setting Y-axis as Sepal length
      .symbolValue((d) => d['Species']) //Setting shapes of symbols as per species
      .margin({
        top: 20,
        right: 20,
        bottom: 40,
        left: 50,
      })
      .size(100)
  );
};
main();
